@@ -1,10 +1,17 @@
-package MooseX::ComposedBehavior::Guts;
-{
-  $MooseX::ComposedBehavior::Guts::VERSION = '0.004';
-}
+package MooseX::ComposedBehavior::Guts 0.005;
 use MooseX::Role::Parameterized 0.21;
 # ABSTRACT: the gooey, meaty bits that help MooseX::ComposedBehavior work
 
+#pod =head1 OVERVIEW
+#pod
+#pod MooseX::ComposedBehavior::Guts contains a bunch of code that is used by
+#pod L<MooseX::ComposedBehavior> to get its job done.  It is basically a hack, and
+#pod relying on any part of its interface would be a I<terrible> idea.
+#pod
+#pod Reading the source, on the other hand, might be useful in understanding what
+#pod the heck is going on, especially if you encounter weird problem.
+#pod
+#pod =cut
 
 use Moose::Util::TypeConstraints;
 
@@ -93,13 +100,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 MooseX::ComposedBehavior::Guts - the gooey, meaty bits that help MooseX::ComposedBehavior work
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 OVERVIEW
 
@@ -110,13 +119,23 @@ relying on any part of its interface would be a I<terrible> idea.
 Reading the source, on the other hand, might be useful in understanding what
 the heck is going on, especially if you encounter weird problem.
 
+=head1 PERL VERSION
+
+This library should run on perls released even a long time ago.  It should work
+on any version of perl released in the last five years.
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
